# -*- coding: utf-8 -*-

"""
firstapicalculator

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

import unittest
from tests.http_response_catcher import HttpResponseCatcher
from firstapicalculator.configuration import Configuration
from firstapicalculator.configuration import Environment
from firstapicalculator.firstapicalculator_client import FirstapicalculatorClient

class ControllerTestBase(unittest.TestCase):

    """All test classes inherit from this base class. It abstracts out
    common functionality and configuration variables set up."""

    @classmethod
    def setUpClass(cls):
        """Class method called once before running tests in a test class."""
        cls.request_timeout = 30
        cls.assert_precision = 0.01
        cls.config = ControllerTestBase.create_configuration()
        cls.client = FirstapicalculatorClient(config=cls.config)

    @staticmethod
    def create_configuration():
        return Configuration(http_call_back=HttpResponseCatcher())



# -*- coding: utf-8 -*-

"""
firstapicalculator

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class OperationTypeEnum(object):

    """Implementation of the 'Operation Type' enum.

    Type of the operation

    Attributes:
        SUM: addition
        SUBTRACT: subtration
        MULTIPLY: multiplication
        DIVIDE: division

    """

    SUM = 'SUM'

    SUBTRACT = 'SUBTRACT'

    MULTIPLY = 'MULTIPLY'

    DIVIDE = 'DIVIDE'



# -*- coding: utf-8 -*-

"""
firstapicalculator

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

import json
import dateutil.parser

from tests.controllers.controller_test_base import ControllerTestBase
from tests.test_helper import TestHelper
from firstapicalculator.api_helper import APIHelper


class SimpleCalculatorControllerTests(ControllerTestBase):

    @classmethod
    def setUpClass(cls):
        super(SimpleCalculatorControllerTests, cls).setUpClass()
        cls.controller = cls.client.simple_calculator
        cls.response_catcher = cls.controller.http_call_back

    # Test the addition of values
    def test_sum(self):
        # Parameters for the API call
        operation = 'SUM'
        x = 10
        y = 3

        # Perform the API call through the SDK function
        result = self.controller.calculate(operation, x, y)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        self.assertEqual('13', self.response_catcher.response.text)

    # Multiplication of two operands
    def test_multiply(self):
        # Parameters for the API call
        operation = 'MULTIPLY'
        x = 5
        y = 6

        # Perform the API call through the SDK function
        result = self.controller.calculate(operation, x, y)

        # Test response code
        self.assertTrue(self.response_catcher.response.status_code in list(range(200, 209)))
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        self.assertEqual('30', self.response_catcher.response.text)

    # Subtraction of two operands
    def test_subtract(self):
        # Parameters for the API call
        operation = 'SUBTRACT'
        x = 9
        y = 5

        # Perform the API call through the SDK function
        result = self.controller.calculate(operation, x, y)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        self.assertEqual('4', self.response_catcher.response.text)

    # Division of two operands
    def test_division(self):
        # Parameters for the API call
        operation = 'DIVIDE'
        x = 25
        y = 5

        # Perform the API call through the SDK function
        result = self.controller.calculate(operation, x, y)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        self.assertEqual('5', self.response_catcher.response.text)

